@@ -57,9 +57,21 @@ static void my_finishCommand(struct mpd_connection *conn) {
 		printErrorAndExit(conn);
 }
 
+static bool
+uri_has_scheme(const char *uri)
+{
+	return strstr(uri, "://") != NULL;
+}
+
 static void
 strip_trailing_slash(char *s)
 {
+	if (uri_has_scheme(s))
+		/* strip slashes only if this string is relative to
+		   the music directory; absolute URLs are not, for
+		   sure */
+		return;
+
 	size_t len = strlen(s);
 
 	if (len == 0)
@@ -454,7 +466,7 @@ enable_disable(int argc, char **argv, struct mpd_connection *conn,
 	bool only = false;
 	int arg;
 
-	if (!strcmp(argv[0], "only")) {
+	if (not_matched != NULL && !strcmp(argv[0], "only")) {
 		only = true;
 		++argv;
 		if (!--argc) {
@@ -530,6 +542,17 @@ cmd_disable(mpd_unused int argc, char **argv, struct mpd_connection *conn)
 			      mpd_send_enable_output);
 }
 
+#if LIBMPDCLIENT_CHECK_VERSION(2,9,0)
+
+int
+cmd_toggle_output(int argc, char **argv, struct mpd_connection *conn)
+{
+	return enable_disable(argc, argv, conn, mpd_send_toggle_output,
+			      mpd_send_toggle_output);
+}
+
+#endif
+
 int cmd_play ( int argc, char ** argv, struct mpd_connection *conn )
 {
 	int song;
@@ -954,6 +977,16 @@ int cmd_volume ( int argc, char ** argv, struct mpd_connection *conn )
 	}
 
 	if (ch.is_relative) {
+#if LIBMPDCLIENT_CHECK_VERSION(2,9,0)
+		if (mpd_connection_cmp_server_version(conn, 0, 18, 0) >= 0) {
+			/* MPD 0.18 knows the "volume" command for
+			   relative changes */
+			if (!mpd_run_change_volume(conn, ch.value))
+				printErrorAndExit(conn);
+			return 1;
+		}
+#endif
+
 		int old_volume;
 
 		status = getStatus(conn);
